==> jc-1.4.0.tar.gz: polyglot/util/Newline.h <==
// class polyglot.util.Newline

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc2875222b1ccf02 polyglot_util_AllowBreak
// @dep_class 77b6315f0d7667d7 polyglot_util_Item
// @dep_class e65ad0113d489ab4 polyglot_util_Newline

// header file dependencies
// @dep_header polyglot_util_AllowBreak

#include "polyglot/util/AllowBreak.h"

#ifndef _JC_polyglot_util_Newline_H_
#define _JC_polyglot_util_Newline_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_Newline$sub_refs	_jc_polyglot_util_Newline$sub_refs;
typedef struct _jc_polyglot_util_Newline$sub_nonrefs	_jc_polyglot_util_Newline$sub_nonrefs;
typedef struct _jc_polyglot_util_Newline$refs	_jc_polyglot_util_Newline$refs;
typedef struct _jc_polyglot_util_Newline$nonrefs	_jc_polyglot_util_Newline$nonrefs;
typedef struct _jc_polyglot_util_Newline$object	_jc_polyglot_util_Newline$object;

typedef const struct _jc_polyglot_util_Newline$vmethods	_jc_polyglot_util_Newline$vmethods;
typedef const struct _jc_polyglot_util_Newline$vtable	_jc_polyglot_util_Newline$vtable;
typedef const struct _jc_polyglot_util_Newline$vtype	_jc_polyglot_util_Newline$vtype;

// Constructors
extern void _jc_polyglot_util_Newline$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint);

// Virtual methods
extern jint _jc_polyglot_util_Newline$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint, jint, jint, jint, jboolean, jboolean);
extern jint _jc_polyglot_util_Newline$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_polyglot_util_Newline$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Newline$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_polyglot_util_Newline$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_polyglot_util_Newline$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint, jint, jint, jint, jboolean, jboolean);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_polyglot_util_Newline$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_polyglot_util_Newline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Item$vmethods	polyglot_util_Item;
	_jc_polyglot_util_AllowBreak$vmethods	polyglot_util_AllowBreak;
	_jc_polyglot_util_Newline$vmethods	polyglot_util_Newline;
};

// Vtype
struct _jc_polyglot_util_Newline$vtype {
	_jc_type			type;
	_jc_polyglot_util_Newline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Newline$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Newline$refs {
    _jc_polyglot_util_Newline$sub_refs	polyglot_util_Newline;
    _jc_polyglot_util_AllowBreak$sub_refs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Item$sub_refs	polyglot_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Newline$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Newline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Item$sub_nonrefs	polyglot_util_Item;
    _jc_polyglot_util_AllowBreak$sub_nonrefs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Newline$sub_nonrefs	polyglot_util_Newline;
};

// Object instance structure
struct _jc_polyglot_util_Newline$object {
	_jc_polyglot_util_Newline$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Newline$vtype	*vtype;
	_jc_polyglot_util_Newline$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Newline$vtype _jc_polyglot_util_Newline$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Newline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Newline$class_object;

#endif	/* _JC_polyglot_util_Newline_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Newline.h <==
// class polyglot.util.Newline

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc2875222b1ccf02 polyglot_util_AllowBreak
// @dep_class 77b6315f0d7667d7 polyglot_util_Item
// @dep_class e65ad0113d489ab4 polyglot_util_Newline

// header file dependencies
// @dep_header polyglot_util_AllowBreak

#include "polyglot/util/AllowBreak.h"

#ifndef _JC_polyglot_util_Newline_H_
#define _JC_polyglot_util_Newline_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_Newline$sub_refs	_jc_polyglot_util_Newline$sub_refs;
typedef struct _jc_polyglot_util_Newline$sub_nonrefs	_jc_polyglot_util_Newline$sub_nonrefs;
typedef struct _jc_polyglot_util_Newline$refs	_jc_polyglot_util_Newline$refs;
typedef struct _jc_polyglot_util_Newline$nonrefs	_jc_polyglot_util_Newline$nonrefs;
typedef struct _jc_polyglot_util_Newline$object	_jc_polyglot_util_Newline$object;

typedef const struct _jc_polyglot_util_Newline$vmethods	_jc_polyglot_util_Newline$vmethods;
typedef const struct _jc_polyglot_util_Newline$vtable	_jc_polyglot_util_Newline$vtable;
typedef const struct _jc_polyglot_util_Newline$vtype	_jc_polyglot_util_Newline$vtype;

// Constructors
extern void _jc_polyglot_util_Newline$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_util_Newline$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_Newline$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_polyglot_util_Newline$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Newline$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_polyglot_util_Newline$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_polyglot_util_Newline$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_polyglot_util_Newline$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_polyglot_util_Newline$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_Newline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Item$vmethods	polyglot_util_Item;
	_jc_polyglot_util_AllowBreak$vmethods	polyglot_util_AllowBreak;
	_jc_polyglot_util_Newline$vmethods	polyglot_util_Newline;
};

// Vtype
struct _jc_polyglot_util_Newline$vtype {
	_jc_type			type;
	_jc_polyglot_util_Newline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Newline$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Newline$refs {
    _jc_polyglot_util_Newline$sub_refs	polyglot_util_Newline;
    _jc_polyglot_util_AllowBreak$sub_refs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Item$sub_refs	polyglot_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Newline$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Newline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Item$sub_nonrefs	polyglot_util_Item;
    _jc_polyglot_util_AllowBreak$sub_nonrefs	polyglot_util_AllowBreak;
    _jc_polyglot_util_Newline$sub_nonrefs	polyglot_util_Newline;
};

// Object instance structure
struct _jc_polyglot_util_Newline$object {
	_jc_polyglot_util_Newline$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Newline$vtype	*vtype;
	_jc_polyglot_util_Newline$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Newline$vtype _jc_polyglot_util_Newline$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Newline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Newline$class_object;

#endif	/* _JC_polyglot_util_Newline_H_ */
